@@ -33,6 +33,7 @@ public enum KameletPrefixSchemeEnum {
     aws_sqs("aws-sqs","aws2-sqs"),
     aws_sqs_batch("aws-sqs-batch","aws2-sqs"),
     aws_sqs_fifo("aws-sqs-fifo","aws2-sqs"),
+    azure_cosmosdb("azure-cosmosdb","azure-cosmosdb"),
     azure_eventhubs("azure-eventhubs","azure-eventhubs"),
     azure_functions("azure-functions","vertx-http"),
     azure_servicebus("azure-servicebus","azure-servicebus"),
@@ -47,8 +48,8 @@ public enum KameletPrefixSchemeEnum {
     chuck_norris("chuck-norris", "http"),
     couchbase("couchbase", "couchbase"),
     dropbox("dropbox", "dropbox"),
-    elasticsearch_rest_index("elasticsearch-index", "elasticsearch"),
-    elasticsearch_rest_search("elasticsearch-search", "elasticsearch"),
+    elasticsearch_index("elasticsearch-index", "elasticsearch"),
+    elasticsearch_search("elasticsearch-search", "elasticsearch"),
     exec("exec", "exec"),
     fhir("fhir", "fhir"),
     file_watch("file-watch", "file-watch"),
@@ -66,6 +67,7 @@ public enum KameletPrefixSchemeEnum {
     google_pubsub("google-pubsub", "google-pubsub"),
     google_sheets("google-sheets", "google-sheets-stream"),
     google_storage("google-storage", "google-storage"),
+    graphql("graphql", "graphql"),
     http("http", "http"),
     http_secured("http-secured", "http"),
     infinispan("infinispan", "infinispan"),
@@ -79,8 +81,11 @@ public enum KameletPrefixSchemeEnum {
     jms_apache_artemis("jms-apache-artemis", "jms"),
     jms_ibm_mq("jms-ibm-mq", "jms"),
     kafka("kafka", "kafka"),
+    kafka_apicurio("kafka-apicurio", "kafka"),
+    kafka_azure("kafka-azure", "kafka"),
     kafka_not_secured("kafka-not-secured", "kafka"),
     kafka_ssl("kafka-ssl", "kafka"),
+    kafka_scram("kafka-scram", "kafka"),
     kubernetes_namespaces("kubernetes-namespaces", "kubernetes-namespaces"),
     kubernetes_nodes("kubernetes-nodes", "kubernetes-nodes"),
     kubernetes_pods("kubernetes-pods", "kubernetes-pods"),
@@ -92,8 +97,10 @@ public enum KameletPrefixSchemeEnum {
     mongodb("mongodb", "mongodb"),
     mqtt("mqtt", "paho"),
     mqtt5("mqtt5", "paho-mqtt5"),
+    ms_exchange("ms-exchange", "imaps"),
     mysql("mysql", "sql"),
     nats("nats", "nats"),
+    opensearch("opensearch", "opensearch"),
     oracle_database("oracle-database", "sql"),
     postgresql("postgresql", "sql"),
     pulsar("pulsar", "pulsar"),
